# PyPlanc

PyPlanc is a wrapper for planc-nmflib, a highly parallel, highly exensibile non-negative matrix factorization library.

This release is an extremely early alpha-do not expect things to be documented or usable, for now!
